#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    https://shiny.posit.co/
#

library(shiny)
library(tidyverse)
library(lubridate)
library(reshape2)

airqual <- read.csv("data/airqualitydata.csv")
airqual <- filter(airqual, !is.na(pod_serial_number) & pod_serial_number != "") %>% mutate(date = as_date(paste0(Year, "-", Month, "-", Day)))
airqual <- airqual %>% select(date, location_name, Hour, PM10, PM2point5, 
                              carbon_monoxide, carbon_monoxide_8hour, sulfur_dioxide, 
                              nitrogen_dioxide, ozone_8hour, ozone_1hour, PM10_scaled, 
                              PM2point5_scaled, carbon_monoxide_8hour_scaled, 
                              sulfur_dioxide_scaled, nitrogen_dioxide_scaled, 
                              ozone_1hour_scaled, ozone_8hour_scaled, carbon_dioxide, 
                              temperature, pressure, humidity)

airqual <- reshape2::melt(airqual, id.vars = c("date", "location_name", "Hour"))

colnames(airqual) <- c("date", "location_name", "Hour", "detectant", "value")

# Define UI for application that draws a histogram
ui <- fluidPage(

    # Application title
    titlePanel("Ann Arbor Air Quality Data"),

    # Sidebar with a slider input for number of bins 
    sidebarLayout(
        sidebarPanel(
          selectInput("location", label = "Air Quality Location", 
                      choices = unique(airqual$location_name), 
                      selected = unique(airqual$location_name)[4], 
                      multiple = FALSE), 
          selectInput("detected", label = "Air Quality Detection", 
                      choices = unique(airqual$detectant), 
                      selected = unique(airqual$detectant)[1], 
                      multiple = FALSE), 
          dateInput("qual_date", label = "Date of Detection", 
                    value = max(airqual$date), min = min(airqual$date), max = max(airqual$date), 
                    format = "yyyy-mm-dd")
        ),

        # Show a plot of the generated distribution
        mainPanel(
           plotOutput("distPlot")
        )
    )
)

# Define server logic required to draw a histogram
server <- function(input, output) {

    airqual_data <- reactive({
      
      airqual_out <- filter(airqual, location_name == input$location &
                              detectant == input$detected & 
                              date == input$qual_date)
      
      print(airqual_out)
      
      return(airqual_out)
      
    })
  
    output$distPlot <- renderPlot({
        
      ad <- airqual_data()
      
      ggplot(ad, aes(x = Hour, y = value)) + 
        geom_point(size = 2) + 
        geom_line(size = 1) + 
        theme_bw() + 
        labs(title = paste0(input$detected, " at ", input$location), 
             subtitle = paste0("On ", input$qual_date), 
             x = "Hour", 
             y = "Value")
      
    })
    
    
    
    
}

# Run the application 
shinyApp(ui = ui, server = server)
